ReconcileReason

Enum ReconcileReason 

pub enum ReconcileReason {
    Unknown,
    ObjectUpdated,
    RelatedObjectUpdated {
        obj_ref: Box<ObjectRef<DynamicObject>>,
    },
    ReconcilerRequestedRetry,
    ErrorPolicyRequestedRetry,
    BulkReconcile,
    Custom {
        reason: String,
    },
}
The reason a reconcile was requested

Note that this reason is deliberately hidden from the reconciler. See https://kube.rs/controllers/reconciler/#reasons-for-reconciliation.

Variants



Unknown

A custom reconcile triggered via reconcile_on



ObjectUpdated

The main object was updated.



RelatedObjectUpdated

A related object was updated through a mapper

The related object traversed its relation up to the object kind you are reconciling. Your object may not have changed, but you may need to update child objects.

Fields

obj_ref: Box<ObjectRef<DynamicObject>>

An object ref to the related object



ReconcilerRequestedRetry

The users reconcile scheduled a reconciliation via an Action



ErrorPolicyRequestedRetry

The users error_policy scheduled a reconciliation via an Action



BulkReconcile

A bulk reconcile was requested via reconcile_all_on



Custom

A custom reconcile reason for custom integrations.

Can be used when injecting elements into the queue stream directly.

Fields

reason: String

A user provided reason through a custom integration