Struct kube_runtime::controller::ReconcilerAction [−][src]
Results of the reconciliation attempt
Fields
requeue_after: Option<Duration>Expand description
Whether (and when) to next trigger the reconciliation if no external watch triggers hit
For example, use this to query external systems for updates, expire time-limited resources, or
(in your error_policy) retry after errors.