pub enum Error<ReconcileErr>where
ReconcileErr: StdError + 'static,{
ApplyFailed(ReconcileErr),
CleanupFailed(ReconcileErr),
AddFinalizer(Error),
RemoveFinalizer(Error),
UnnamedObject,
InvalidFinalizer,
}Expand description
Errors from the finalizer helper
Note that this error takes the user’s error as a type parameter. This makes its usage within loosely typed errors (such as anyhow) difficult.
Using proper error enums such as ones generated by e.g. thiserror is the easiest. See https://github.com/kube-rs/kube/discussions/982
Variants
ApplyFailed(ReconcileErr)
User side Event::Apply branch failed
CleanupFailed(ReconcileErr)
User side Event::Cleanup branch failed
AddFinalizer(Error)
The patch call adding a finalizer failed
RemoveFinalizer(Error)
The patch call removing a finalizer failed
UnnamedObject
The object requested to be patched has no name
This should not happen unless you are hand crafting the object without a name
InvalidFinalizer
The finalizer path was invalid
This should not happen, the path is constructed internally and should be
valid as far as json_patch is concerned.