Struct kube_runtime::reflector::ObjectRef [−][src]
pub struct ObjectRef<K: Resource> { pub name: String, pub namespace: Option<String>, // some fields omitted }
A typed and namedspaced (if relevant) reference to a Kubernetes object
K may be either the object type or DynamicObject, in which case the
type is stored at runtime. Erased ObjectRefs pointing to different types
are still considered different.
use kube_runtime::reflector::ObjectRef; use k8s_openapi::api::core::v1::{ConfigMap, Secret}; assert_ne!( ObjectRef::<ConfigMap>::new("a").erase(), ObjectRef::<Secret>::new("a").erase(), );
Fields
name: StringExpand description
The name of the object
namespace: Option<String>Expand description
The namespace of the object
May only be None if the kind is cluster-scoped (not located in a namespace).
Note that it is acceptable for an ObjectRef to a cluster-scoped resource to
have a namespace. These are, however, not considered equal:
assert_ne!(ObjectRef::<ConfigMap>::new("foo"), ObjectRef::new("foo").within("bar"));
Implementations
impl<K: Resource> ObjectRef<K> where
K::DynamicType: Default, [src]
impl<K: Resource> ObjectRef<K> where
K::DynamicType: Default, [src]impl<K: Resource> ObjectRef<K>[src]
impl<K: Resource> ObjectRef<K>[src]#[must_use]pub fn new_with(name: &str, dyntype: K::DynamicType) -> Self[src]
#[must_use]pub fn within(self, namespace: &str) -> Self[src]
#[must_use]pub fn from_obj_with(obj: &K, dyntype: K::DynamicType) -> Self where
K: Resource, [src]
#[must_use]pub fn from_obj_with(obj: &K, dyntype: K::DynamicType) -> Self where
K: Resource, [src]Creates ObjectRef from the resource and dynamic type. Panics if name is missing (name always exists if the object was returned from the apiserver)
#[must_use]pub fn from_owner_ref(
namespace: Option<&str>,
owner: &OwnerReference,
dyntype: K::DynamicType
) -> Option<Self>[src]
#[must_use]pub fn from_owner_ref(
namespace: Option<&str>,
owner: &OwnerReference,
dyntype: K::DynamicType
) -> Option<Self>[src]Create an ObjectRef from an OwnerReference
Returns None if the types do not match.
#[must_use]pub fn into_kind_unchecked<K2: Resource>(
self,
dt2: K2::DynamicType
) -> ObjectRef<K2>[src]
#[must_use]pub fn into_kind_unchecked<K2: Resource>(
self,
dt2: K2::DynamicType
) -> ObjectRef<K2>[src]Convert into a reference to K2
Note that no checking is done on whether this conversion makes sense. For example, every Service
has a corresponding Endpoints, but it wouldn’t make sense to convert a Pod into a Deployment.
pub fn erase(self) -> ObjectRef<DynamicObject>[src]