pub trait Backoff:
Iterator<Item = Duration>
+ Send
+ Sync
+ Unpin {
// Required method
fn reset(&mut self);
}Expand description
A mostly internal trait to allow resetting backoff based on a reset duration
pub trait Backoff:
Iterator<Item = Duration>
+ Send
+ Sync
+ Unpin {
// Required method
fn reset(&mut self);
}A mostly internal trait to allow resetting backoff based on a reset duration