pub enum Error {
InitialListFailed(Error),
WatchStartFailed(Error),
WatchError(Box<Status>),
WatchFailed(Error),
NoResourceVersion,
}Expand description
Errors that a watcher can emit
These are all considered retryable from a watcher’s point of view, even though they may require patching of rbac/netpols in the background to fix.
To avoid constantly looping errors, make sure backoff is applied.
Variants
InitialListFailed(Error)
Received a raw error while performing an api.list
WatchStartFailed(Error)
Received a raw error while starting an api.watch
WatchError(Box<Status>)
Received a WatchEvent::Error from the apiserver
WatchFailed(Error)
Received a raw error while watching
NoResourceVersion
Missing resource version field from api server