Runs a user-supplied reconciler function on objects when they (or related objects) are updated
Structs
- Action
- Results of the reconciliation attempt
- Config
- Accumulates all options that can be used on a
Controllerinvocation. - Controller
- Controller for a Resource
K - Reconcile
Request - A request to reconcile an object, annotated with why that request was made.
Enums
- Error
- Errors returned by the applier and visible in a controller stream if inspecting it
- Reconcile
Reason - The reason a reconcile was requested
Functions
- applier
- Apply a reconciler to an input stream, with a given retry policy
- trigger_
owners - Enqueues any owners of type
KOwnerfor reconciliation - trigger_
self - Enqueues the object itself for reconciliation
- trigger_
with - Helper for building custom trigger filters, see the implementations of
trigger_selfandtrigger_ownersfor some examples.
Type Aliases
- Runner
Error - The reasons the internal runner can fail