Watches a Kubernetes Resource for changes, with error recovery
See watcher for the primary entry point.
Structs
- Config
- Accumulates all options that can be used on the watcher invocation.
- Default
Backoff - Default watcher backoff inspired by Kubernetes’ client-go.
- Exponential
Backoff - A struct with a manually configured exponential backoff
Enums
- Error
- Errors that a watcher can emit
- Event
- Watch events returned from the
watcher - Initial
List Strategy - Configurable watcher listwatch semantics
- List
Semantic - Configurable list semantics for
watcherrelists
Functions
- metadata_
watcher - Watches a Kubernetes Resource for changes continuously and receives only the metadata
- watch_
object - Watch a single named object for updates
- watcher
- Watches a Kubernetes Resource for changes continuously
Type Aliases
- Result
- Type alias for Result with a
watcher::Erroras default.